<?php
/**
 * Menu Post Type
 *
 * This file creates the menu
 * post type and registers its
 * taxonomy and features.
 *
 * @package WordPress
 * @subpackage Bottega
 * @since Bottega 2.0.0
 */

// Register Menu Post Type

		register_post_type( 'organizedthemes_menu',
			array(
				'labels' 				=> array(
				'name' 					=> __( 'Menu', 'organizedthemes' ),
				'singular_name' 		=> __( 'Menu', 'organizedthemes' ),
				'add_new' 				=> __( 'Add New Menu Item', 'organizedthemes' ),
				'add_new_item' 			=> __( 'Add New Menu Item', 'organizedthemes' ),
				'edit' 					=> __( 'Edit Menu Item', 'organizedthemes' ),
				'edit_item' 			=> __( 'Edit Menu Item', 'organizedthemes' ),
				'view' 					=> __( 'View Menu Item', 'organizedthemes' ),
				'view_item' 			=> __( 'View Menu Item', 'organizedthemes' ),
				'not_found' 			=> __( 'No menu items', 'organizedthemes' ),
				'not_found_in_trash' 	=> __( 'Your food isn"t in the trash', 'organizedthemes' ),
			),
				'public' 				=> true,
				'show_ui' 				=> true,
				'hierarchical' 			=> true,
				'publicly_queryable' 	=> true,
				'exclude_from_search' 	=> false,
				'rewrite'				=> array( 'slug' => 'menu-item' ),
				'menu_icon' 			=> get_stylesheet_directory_uri() . '/images/food.png',
	    		'supports' 				=> array('title', 'editor', 'thumbnail', 'page-attributes')
			)
			
		);
	
	// Register Sponsor Group Taxonomy
		register_taxonomy( 'menu_group', 'organizedthemes_menu', 
			array( 
				'hierarchical' => true, 
					'labels' => array(
						'name' 				=> __( 'Menu Group', 'organizedthemes' ),
						'singular_name' 	=> __( 'Menu Group', 'organizedthemes' ),
						'search_items' 		=> __( 'Search Menu Groups', 'organizedthemes' ),
						'popular_items' 	=> __( 'Popular Menu Groups', 'organizedthemes' ),
						'all_items' 		=> __( 'All Menu Groups', 'organizedthemes' ),
						'parent_item' 		=> __( 'Parent Menu Group', 'organizedthemes' ),
						'parent_item_colon' => __( 'Parent Menu Group:', 'organizedthemes' ),
						'edit_item' 		=> __( 'Edit Menu Group', 'organizedthemes' ),
						'update_item' 		=> __( 'Update Menu Group', 'organizedthemes' ),
						'add_new_item' 		=> __( 'Add New Menu Group', 'organizedthemes' ),
						'new_item_name' 	=> __( 'New Menu Group Name', 'organizedthemes' ),
					), 
				'query_var' => true,
				'show_in_nav_menus' => true,
				'rewrite' => array( 'slug' => 'menu', 'with_front' => false )
				) 
		);

//  Add columns to staff dashboard
//  http://wptheming.com/2010/07/column-edit-pages/

add_filter("manage_edit-organizedthemes_menu_columns", "organizedthemes_menu_edit_columns");
add_action("manage_pages_custom_column",  "organizedthemes_menu_columns_display", 10, 2);

 
function organizedthemes_menu_edit_columns($staff_columns){
	$organizedthemes_menu_columns = array(
		"cb" 								=> "<input type=\"checkbox\" />",
		"organizedthemes_menu_thumbnail" 	=> __('Featured Image', 'organizedthemes'),
		"title" 							=> __('Name', 'organizedthemes'),
		"organizedthemes_menu_price" 		=> __('Price', 'organizedthemes'),
		"organizedthemes_menu_group" 		=> __('Menu Group', 'organizedthemes'),
		"organizedthemes_menu_content" 		=> __('Description', 'organizedthemes'),	);
	return $organizedthemes_menu_columns;
}
 
function organizedthemes_menu_columns_display($organizedthemes_menu_columns, $post_id){

	switch ($organizedthemes_menu_columns)
	
	{
		// Code from: http://wpengineer.com/display-post-thumbnail-post-page-overview
		
		case "organizedthemes_menu_thumbnail": //Adds the staff members image to the columns
			$width = (int) 200;
			$height = (int) 200;
			$thumbnail_id = get_post_meta( $post_id, '_thumbnail_id', true );
			
			// Display the featured image in the column view if possible
			if ($thumbnail_id) {
				$thumb = wp_get_attachment_image( $thumbnail_id, array($width, $height), true );
			}
			if ( isset($thumb) ) {
				echo $thumb;
			} else {
				echo __('Add a featured image to include a picture', 'organizedthemes');
			}
			break;

		case "organizedthemes_menu_price": //Adds the price to the columns
			$custom = get_post_custom();
			echo $custom["_price"][0];
			break;	
			
		case "organizedthemes_menu_content": //Adds the excerpt to the description column
			the_excerpt();
			break;	
		
		case "organizedthemes_menu_group": //Adds the menu group to the columns
			echo get_the_term_list($post->ID, 'menu_group', '', ', ','');
			break;	
		
	}
}

//change title to slide description
	function organizedthemes_menu_item_title( $title ){
	     $screen = get_current_screen();
	 
	     if  ( 'organizedthemes_menu' == $screen->post_type ) {
	          $title = 'Enter Menu Item Name';
	     }
	 
	     return $title;
	}
	 
	add_filter( 'enter_title_here', 'organizedthemes_menu_item_title' );
		
// Shortcode uses this format [menu group="burgers"]
// where burgers is the slug of the taxonomy being used

// Shortcodes for Menu Groups

	add_shortcode( 'menu', 'organizedthemes_menu_shortcode' );
	
	function organizedthemes_menu_shortcode( $atts ){
	 	
	 	extract(shortcode_atts(array(
		  'group' => 1,
		), $atts));
	 	
	    ob_start();
	 	
	 	global $post;
	 	
	    $args = array(
	    	'tax_query' => array(
	   		        array(
	   		            'taxonomy' => 'menu_group',
	   		            'terms' => $group,
	   		            'field' => 'slug'
	   		        )
	   		    ),
	    	'orderby' => 'menu_order', 
	    	'order' => 'ASC', 
	    	'showposts' => -1 
	    	);
	    	
	    $loop = new WP_Query( $args );
	 	
	    echo '<ul class="item-list space">';
	 	
	        while ( $loop->have_posts() ) : $loop->the_post();
	        ?>
	 
	            <?php get_template_part( 'layouts/menu-item' ); ?>
	 
	        <?php endwhile; ?>
	 
	    <?php 
	    
	    echo '</ul>';
	 
	    $content = ob_get_contents();
	    ob_end_clean();
	    
	    return $content;
	
	}