<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function optionsframework_option_name() {

	$optionsframework_settings = get_option('optionsframework');
	
	// Edit 'options-theme-customizer' and set your own theme name instead
	$optionsframework_settings['id'] = 'bottega';
	update_option('optionsframework', $optionsframework_settings);
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {
	
	// Home Page Options
	$home_media = array(
		"image" => __( 'Slideshow', 'organizedthemes' ),
		"video" => __( 'Video', 'organizedthemes' ),
	);
	
	// Graphic logo or dynamic text
	$logo_type = array(
		"text" => __( 'Text', 'organizedthemes' ),
		"image" => __( 'Image', 'organizedthemes' ),
	);
	
	// True or False
	$tf = array(
		"true" => __( 'Yes', 'organizedthemes' ),
		"false" => __( 'No', 'organizedthemes' ),
	);	
	
	// Yes or No
	$yes = array(
		"true" => __( 'Yes', 'organizedthemes' ),
		"false" => __( 'No', 'organizedthemes' ),
	);
	
	// Transition Type
	$transition = array(
		"fade" => __( 'Fade', 'organizedthemes' ),
		"slide" => __( 'Slide', 'organizedthemes' )
	);
	
	// Numbers
	$numbers = array("1" => "1","2" => "2","3" => "3","4" => "4","5" => "5","6" => "6","7" => "7","8" => "8","9" => "9","10" => "10");
	
	// content or excerpt
		$content_type = array(
			"excerpt" => __( 'Excerpt', 'organizedthemes' ),
			"content" => __( 'Full Content', 'organizedthemes' )
			);
	
	// content or excerpt
		$feature_type = array(
			"menu" => __( 'Menu Group', 'organizedthemes' ),
			"post" => __( 'Blog Posts', 'organizedthemes' ),
			"hidden" => __( 'Do Not Display', 'organizedthemes' )
			);
	
	// Background Options
		$background_repeat = array(
			"repeat" => __( 'Repeat All', 'organizedthemes' ),
			"repeat-y" => __( 'Repeat Vertically', 'organizedthemes' ),
			"repeat-x" => __( 'Repeat Horizontally', 'organizedthemes' ),
			"no-repeat" => __( 'No Repeat', 'organizedthemes' )
			);
		
		$background_attachment = array(
			"scroll" => __( 'Scroll', 'organizedthemes' ),
			"fixed" => __( 'Fixed', 'organizedthemes' )
			);
		
		$background_position_x = array(
			"left" => __( 'Left', 'organizedthemes' ),
			"center" => __( 'Center', 'organizedthemes' ),
			"right" => __( 'Right', 'organizedthemes' )
			);
		
		$background_position_y = array(
			"top" => __( 'Top', 'organizedthemes' ),
			"center" => __( 'Center', 'organizedthemes' ),
			"bottom" => __( 'Bottom', 'organizedthemes' )
			);
	
	// lightbox styling
		$light_style = array(
			"default" => __( 'Default', 'organizedthemes' ),
			"carbono" => __( 'Carbono', 'organizedthemes' ),
			"classic" => __( 'Classic', 'organizedthemes' ),
			"classic_dark" => __( 'Classic Dark', 'organizedthemes' ),
			"evolution" => __( 'Evolution', 'organizedthemes' ),
			"evolution_dark" => __( 'Evolution Dark', 'organizedthemes' ),
			"facebook" => __( 'Facebook', 'organizedthemes' ),
			"minimal" => __( 'Minimalist', 'organizedthemes' ),
			"minimal_dark" => __( 'Minimalist Dark', 'organizedthemes' ),
			"white" => __( 'White and Green', 'organizedthemes' )
		);
	
	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the menu group taxonomy into an array
	$menu_group = array();  
	$menu_group[''] = __( 'Select a menu group to include this section', 'organizedthemes' );
	$menu_group_obj = get_categories('taxonomy=menu_group');
	foreach ($menu_group_obj as $menu_group_id) {
		$menu_group[$menu_group_id->cat_ID] = $menu_group_id->cat_name;
	}
		
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = '';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
	
	$typography_mixed_fonts = array_merge( options_typography_get_os_fonts() , options_typography_get_google_fonts() );
	asort($typography_mixed_fonts);
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_stylesheet_directory_uri() . '/images/';
		
	$options = array();
		
	$options[] = array( "name" => __( 'Identity', 'organizedthemes' ),
						"type" => "heading");
						
	$options['header_blog_title'] = array( "name" => __( 'Text or Graphic Logo', 'organizedthemes' ),
						"desc" => __( 'Choose between a graphic logo or the site title.', 'organizedthemes' ),
						"id" => "header_blog_title",
						"std" => "Text",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $logo_type);
	
	$options['logo'] = array( "name" => __( 'Logo', 'organizedthemes' ),
						"desc" => __( 'Upload a graphic logo here.', 'organizedthemes' ),
						"id" => "logo",
						"type" => "upload");
	
	$options[] = array( "name" => __( 'Favicon', 'organizedthemes' ),
						"desc" => __( 'Upload a favicon (small icon that sits beside your websites address in a browser navigation bar here.', 'organizedthemes' ),
						"id" => "favicon",
						"std" => "",
						"type" => "upload");
						
	$options[] = array( "name" => __( 'Apple Shortcut Icon', 'organizedthemes' ),
						"desc" => __( 'Upload an icon for an iOS shortcut icon here.  Should be 114 pixels square.', 'organizedthemes' ),
						"id" => "apple",
						"std" => "",
						"type" => "upload");
						
	$options[] = array( "name" => __( 'Include Lightbox Gallery', 'organizedthemes' ),
						"desc" => __( 'If you would like to disable the fancybox, lightbox gallery, select no here.', 'organizedthemes' ),
						"id" => "gallery",
						"std" => "yes",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $yes);
	
	$options[] = array( "name" => __( 'Lightbox Style', 'organizedthemes' ),
						"desc" => __( 'Choose a style for the pop-up lightbox.', 'organizedthemes' ),
						"id" => "lightbox_style",
						"std" => "classic",
						"type" => "select",
						"class" => "tiny", //mini, tiny, small
						"options" => $light_style);
	
	$options[] = array( "name" => __( 'Display Excerpt Or Full Content In Blog', 'organizedthemes' ),
						"desc" => __( 'You can choose to display your full post content or only an excerpt on archive pages.', 'organizedthemes' ),
						"id" => "content_excerpt",
						"std" => "yes",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $content_type);
	
	$options[] = array( "name" => __( 'Header Phone Text', 'organizedthemes' ),
						"desc" => __( 'Enter any text such as a phone number you would like to have in the header.', 'organizedthemes' ),
						"id" => "header_phone",
						"std" => "",
						"type" => "text");	
	
	$options[] = array( "name" => __( 'Header Phone Link', 'organizedthemes' ),
						"desc" => __( 'To make your phone number clickable on mobile devices, enter it here with "tel:+" before it.  Leave all other punctuation out.', 'organizedthemes' ),
						"id" => "header_phone_number",
						"std" => "tel:+",
						"type" => "text");
					
	$options[] = array( "name" => __( 'Footer Contact', 'organizedthemes' ),
						"desc" => "If you'd like to have text in the footer, enter it here.",
						"id" => "footer_contact",
						"std" => "",
						"type" => "text");	
																		
	$options[] = array( "name" => __( 'Footer Social Media Links', 'organizedthemes' ),
						"desc" => __( 'Add links to various social media networks.  All are optional.', 'organizedthemes' ),
						"type" => "info");
								
	$options[] = array( "name" => __( 'Flickr', 'organizedthemes' ),
						"desc" => "",
						"id" => "flickr",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Instagram', 'organizedthemes' ),
						"desc" => "",
						"id" => "instagram",
						"std" => "",
						"type" => "text");	
								
	$options[] = array( "name" => __( 'YouTube', 'organizedthemes' ),
						"desc" => "",
						"id" => "youtube",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'Vimeo', 'organizedthemes' ),
						"desc" => "",
						"id" => "vimeo",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'Facebook', 'organizedthemes' ),
						"desc" => "",
						"id" => "Facebook",
						"std" => "",
						"type" => "text");
								
	$options[] = array( "name" => __( 'Twitter', 'organizedthemes' ),
						"desc" => "",
						"id" => "twitter",
						"std" => "",
						"type" => "text");	
					
	$options[] = array( "name" => __( 'Yelp', 'organizedthemes' ),
						"desc" => "",
						"id" => "yelp",
						"std" => "",
						"type" => "text");	
	
	$options[] = array( "name" => __( 'Pinterest', 'organizedthemes' ),
						"desc" => "",
						"id" => "pinterest",
						"std" => "",
						"type" => "text");	
					
	$options[] = array( "name" => __( 'Foursquare', 'organizedthemes' ),
						"desc" => "",
						"id" => "foursquare",
						"std" => "",
						"type" => "text");	
										
	$options[] = array( "name" => __( 'Google+', 'organizedthemes' ),
						"desc" => "",
						"id" => "google",
						"std" => "",
						"type" => "text");	
								
	$options[] = array( "name" => __( 'Linked In', 'organizedthemes' ),
						"desc" => "",
						"id" => "linkedin",
						"std" => "",
						"type" => "text");	
					
	$options[] = array( "name" => __( 'Custom Icon', 'organizedthemes' ),
						"desc" => __( 'To add a custom service, upload a 32 by 32 pixel icon here', 'organizedthemes' ),
						"id" => "custom_icon",
						"std" => "",
						"type" => "upload");
	
	$options[] = array( "name" => __( 'Custom Icon URL', 'organizedthemes' ),
						"desc" => "",
						"id" => "custom_icon_url",
						"std" => "",
						"type" => "text");	
	
	$options[] = array( "name" => __( 'Include RSS Icon', 'organizedthemes' ),
						"desc" => __( '', 'organizedthemes' ),
						"id" => "rss_subscribe",
						"std" => "yes",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $yes);
	
	$options[] = array( "name" => __( 'Advanced Options', 'organizedthemes' ),
						"desc" => __( '', 'organizedthemes' ),
						"type" => "info");
	
	$options[] = array( "name" => __( 'URL Slug For Staff Members', 'organizedthemes' ),
						"desc" => __( 'You can enter a new slug for your staff member\'s individual URL\'s here.  Must be all lowercase with no special characters or spaces.  After changing this you will need to resave your permalinks to prevent not found errors.', 'organizedthemes' ),
						"id" => "staff_slug",
						"std" => "staff",
						"type" => "text");
	
	$options[] = array( 'name' => __( 'Disable Theme Updates', 'organizedthemes' ),
		'desc' => __( 'Disables the theme updater feature.', 'organizedthemes' ),
		'id' => 'disable_theme_updater',
		'std' => false,
		'type' => 'checkbox' );
					
// Home Page Options		
	$options[] = array( "name" => __( 'Home Page', 'organizedthemes' ),
						"type" => "heading");	
	
	$options[] = array( "name" => __( 'Featured Row', 'organizedthemes' ),
						"desc" => __( 'Choose the source for the home page featured row (the small boxes below the slideshow).  You can choose a menu group, blog posts or not to use the row.', 'organizedthemes' ),
						"id" => "feature_type",
						"std" => "post",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $feature_type);
	
	$options[] = array( "name" => __( 'Featured Row Blog Category', 'organizedthemes' ),
						"desc" => __( '"Select a category for the featured row of posts on your home page.', 'organizedthemes' ),
						"id" => "features",
						"type" => "select",
						"options" => $options_categories);
				
	$options[] = array( "name" => __( 'Featured Row Menu Group', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your featured row.', 'organizedthemes' ),
						"id" => "featured_menu",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Automatically Play Slideshow', 'organizedthemes' ),
						"desc" => __( 'Choose yes to have the slideshow begin sliding once the page loads.  If you are using videos, we recommend setting this to NO.', 'organizedthemes' ),
						"id" => "auto",
						"std" => "true",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $tf);
	
	$options[] = array( "name" => __( 'Slide Bullets', 'organizedthemes' ),
						"desc" => __( 'Display current slide indicator circles.', 'organizedthemes' ),
						"id" => "bullets",
						"std" => "true",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $tf);
	
	$options[] = array( "name" => __( 'Animation Type', 'organizedthemes' ),
						"desc" => __( 'The slideshow can either use a fade or a slide for transitions.', 'organizedthemes' ),
						"id" => "type",
						"std" => "slide",
						"type" => "select",
						"class" => "mini", //mini, tiny, small
						"options" => $transition);
	
	$options[] = array( "name" => __( 'Slide Duration','organizedthemes'),
						"desc" => __( 'The amount of time in milliseconds that each slide will be visible.','organizedthemes'),
						"id" => "duration",
						"std" => "5000",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Animation Duration','organizedthemes'),
						"desc" => __( 'The amount of time in milliseconds that it takes to change a slide','organizedthemes'),
						"id" => "transition",
						"std" => "750",
						"type" => "text");
	
						
// Menu Page Template Options		
	$options[] = array( "name" => __( 'Menu Page', 'organizedthemes' ),
						"type" => "heading");
	
	$options[] = array( "name" => __( 'Instructions', 'organizedthemes' ),
						"desc" => __( 'Just choose the menu sections you would like to include on your menu page template below.  Each section will be displayed in the order selected here.  Each section is optional.  Only Menu Groups that have a <em>Menu Item</em> published in them will be visible to choose.', 'organizedthemes' ),
						"type" => "info");
						
	$options[] = array( "name" => __( 'Menu Group 1', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your first menu section.', 'organizedthemes' ),
						"id" => "menu_1",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 1 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your first menu group list.', 'organizedthemes' ),
						"id" => "menu_title_1",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 1 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_1",
						"std" => "",
						"type" => "textarea"); 
	
	$options[] = array( "name" => __( 'Menu Group 2', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_2",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 2 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_2",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 2 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_2",
						"std" => "",
						"type" => "textarea"); 
	
	$options[] = array( "name" => __( 'Menu Group 3', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_3",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 3 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_3",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 3 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_3",
						"std" => "",
						"type" => "textarea"); 
						
	$options[] = array( "name" => __( 'Menu Group 4', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_4",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 4 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_4",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 4 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_4",
						"std" => "",
						"type" => "textarea"); 
						
	$options[] = array( "name" => __( 'Menu Group 5', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_5",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 5 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_5",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 5 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_5",
						"std" => "",
						"type" => "textarea"); 
						
	$options[] = array( "name" => __( 'Menu Group 6', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_6",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 6 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_6",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 6 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_6",
						"std" => "",
						"type" => "textarea");
						 
	$options[] = array( "name" => __( 'Menu Group 7', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_7",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 7 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_7",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 7 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_7",
						"std" => "",
						"type" => "textarea"); 
						
	$options[] = array( "name" => __( 'Menu Group 8', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_8",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 8 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_8",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 8 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_8",
						"std" => "",
						"type" => "textarea"); 
						
	$options[] = array( "name" => __( 'Menu Group 9', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_9",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 9 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_9",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 9 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_9",
						"std" => "",
						"type" => "textarea"); 
						
	$options[] = array( "name" => __( 'Menu Group 10', 'organizedthemes' ),
						"desc" => __( 'Select a menu group for your second menu section.', 'organizedthemes' ),
						"id" => "menu_10",
						"type" => "select",
						"options" => $menu_group);
	
	$options[] = array( "name" => __( 'Menu Group 10 Title', 'organizedthemes' ),
						"desc" => __( 'The title that will appear above your second menu group list.', 'organizedthemes' ),
						"id" => "menu_title_10",
						"std" => "",
						"type" => "text");
	
	$options[] = array( "name" => __( 'Menu Group 10 Description', 'organizedthemes' ),
						"desc" => __( 'This will appear above the listing of your menu group.', 'organizedthemes' ),
						"id" => "menu_description_10",
						"std" => "",
						"type" => "textarea"); 










	
// Styling Options						
	$options[] = array( "name" => __( 'Styling', 'organizedthemes' ),
						"type" => "heading");
						
	$options[] = array(
		'name' => __('', 'organizedthemes'),
		'desc' => __('Many of these styling options are available in the theme customizer.  For the best experience, make changes <a href="'.home_url().'/wp-admin/customize.php">there.</a>', 'organizedthemes'),
		'type' => 'info');
	
	$options[] = array(
		'name' => __('Background', 'organizedthemes'),
		'type' => 'info');
	
	$options['background_image'] = array( "name" => __( 'Background Image', 'organizedthemes' ),
						"desc" => __( 'Upload a background image here.', 'organizedthemes' ),
						"id" => "background_image",
						"std" => get_template_directory_uri() . '/backgrounds/background-metal.jpg',
						"type" => "upload");
	
	$options['background_repeat'] = array( "name" => __( 'Background Repeat', 'organizedthemes' ),
						"desc" => __( 'Set how your background iamge repeats.', 'organizedthemes' ),
						"id" => "background_repeat",
						"std" => "repeat",
						"type" => "select",
						"options" => $background_repeat);
	
	$options['background_attachment'] = array( "name" => __( 'Background Attachment', 'organizedthemes' ),
						"desc" => __( 'Set how your background iamge is attached.', 'organizedthemes' ),
						"id" => "background_attachment",
						"std" => "scroll",
						"type" => "select",
						"options" => $background_attachment);
	
	$options['background_position_horizontal'] = array( "name" => __( 'Background Position (horizontal)', 'organizedthemes' ),
						"desc" => __( 'Chose where the background image begins horizontally.', 'organizedthemes' ),
						"id" => "background_position_horizontal",
						"std" => "center",
						"type" => "select",
						"options" => $background_position_x);
	
	$options['background_position_vertical'] = array( "name" => __( 'Background Position (vertical)', 'organizedthemes' ),
						"desc" => __( 'Chose where the background image begins vertically.', 'organizedthemes' ),
						"id" => "background_position_vertical",
						"std" => "top",
						"type" => "select",
						"options" => $background_position_y);
	
	$options['background_color'] = array( "name" => __( 'Background Color', 'organizedthemes' ),
						"desc" => __( 'Choose a background color', 'organizedthemes' ),
						"id" => "background_color",
						"std" => "#222222",
						"type" => "color");	
	
	
	$options[] = array(
		'name' => __('Header', 'organizedthemes'),
		'type' => 'info');
	
	$options['header_image'] = array( "name" => __( 'Header Image', 'organizedthemes' ),
						"desc" => __( 'Upload a header image here.', 'organizedthemes' ),
						"id" => "header_image",
						"std" => get_template_directory_uri() . '/images/header.jpg',
						"type" => "upload");
	
	$options['header_repeat'] = array( "name" => __( 'Header Repeat', 'organizedthemes' ),
						"desc" => __( 'Set how your header iamge repeats.', 'organizedthemes' ),
						"id" => "header_repeat",
						"std" => "no-repeat",
						"type" => "select",
						"options" => $background_repeat);
	
	$options['header_attachment'] = array( "name" => __( 'Header Attachment', 'organizedthemes' ),
						"desc" => __( 'Set how your header iamge is attached.', 'organizedthemes' ),
						"id" => "header_attachment",
						"std" => "scroll",
						"type" => "select",
						"options" => $background_attachment);
	
	$options['header_position_horizontal'] = array( "name" => __( 'Header Position (horizontal)', 'organizedthemes' ),
						"desc" => __( 'Chose where the header image begins horizontally.', 'organizedthemes' ),
						"id" => "header_position_horizontal",
						"std" => "center",
						"type" => "select",
						"options" => $background_position_x);
	
	$options['header_position_vertical'] = array( "name" => __( 'Header Position (vertical)', 'organizedthemes' ),
						"desc" => __( 'Chose where the header image begins vertically.', 'organizedthemes' ),
						"id" => "header_position_vertical",
						"std" => "top",
						"type" => "select",
						"options" => $background_position_y);
	
	$options['header_color'] = array( "name" => __( 'Header Color', 'organizedthemes' ),
						"desc" => __( 'Choose a header color', 'organizedthemes' ),
						"id" => "header_color",
						"std" => "#0D0D0C",
						"type" => "color");	
	
	$options['phone_top'] = array( "name" => __( 'Phone Top Distance', 'organizedthemes' ),
						"desc" => __( 'Can be used to position your header phone number in pixels from the top.', 'organizedthemes' ),
						"id" => "phone_top",
						"std" => "",
						"type" => "text");
	
	$options['phone_right'] = array( "name" => __( 'Phone Right Distance', 'organizedthemes' ),
						"desc" => __( 'Can be used to position your header phone number in pixels from the right.', 'organizedthemes' ),
						"id" => "phone_top",
						"std" => "",
						"type" => "text");
	
	
	$options[] = array(
		'name' => __('Typeography', 'organizedthemes'),
		'type' => 'info');
	
	$options['site_title_font'] = array( 'name' => __( 'Site Title', 'organizedthemes' ),
			'desc' => __( 'Choose the type for your text logo.', 'organizedthemes' ),
			'id' => 'site_title_font',
			'std' => array( 'size' => '50px', 'face' => 'Rokkitt, serif', 'color' => '#ffffff'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'color' => false )
			);
	
	$options['site_title_font_color'] = array( "name" => __( 'Site Title Color', 'organizedthemes' ),
						"desc" => __( 'Sets the color for the title.', 'organizedthemes' ),
						"id" => "site_title_font_color",
						"std" => "",
						"type" => "color");
	
	$options['site_title_font_hover'] = array( "name" => __( 'Site Title Hover Color', 'organizedthemes' ),
						"desc" => __( 'Sets the color for the title while being hovered.', 'organizedthemes' ),
						"id" => "site_title_font_hover",
						"std" => "",
						"type" => "color");
			
	$options['body_font'] = array( 'name' => __( 'Body Font', 'organizedthemes' ),
			'desc' => __( 'This is used for the main conent and widgets.', 'organizedthemes' ),
			'id' => 'body_font',
			'std' => array( 'size' => '15px', 'face' => 'PT Sans, sans-serif', 'color' => '#000000'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'color' => false )
			);
	
	$options['body_font_color'] = array( "name" => __( 'Body Font Color', 'organizedthemes' ),
						"desc" => __( 'The color of your main text.', 'organizedthemes' ),
						"id" => "body_font_color",
						"std" => "",
						"type" => "color");	
	
	$options['widget_title'] = array( 'name' => __( 'Widget Titles', 'organizedthemes' ),
			'desc' => __( 'The heading at the top of a widget.', 'organizedthemes' ),
			'id' => 'widget_title',
			'std' => array( 'size' => '24px', 'face' => 'Rokkitt, serif', 'color' => '#000000'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'color' => false )
			);
	
	$options['widget_title_color'] = array( "name" => __( 'Widget Title Color', 'organizedthemes' ),
						"desc" => __( 'The color of your widget titles', 'organizedthemes' ),
						"id" => "widget_title_color",
						"std" => "",
						"type" => "color");	
	
	$options['widget_title_border'] = array( "name" => __( 'Widget Title Border Color', 'organizedthemes' ),
						"desc" => __( 'The color of the line below widget titles and between posts', 'organizedthemes' ),
						"id" => "widget_title_border",
						"std" => "",
						"type" => "color");	
	
	$options['heading_font'] = array( 'name' => __( 'Headings', 'organizedthemes' ),
			'desc' => __( 'Choose a font for your page titles and other headings (h1, h2, h3, h4, h5, h6)', 'organizedthemes' ),
			'id' => 'heading_font',
			'std' => array( 'size' => '24px', 'face' => 'Rokkitt, serif', 'color' => '#000000'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'sizes' => false,
				'color' => false )
			);
	
	$options['heading_color'] = array( "name" => __( 'Heading Color', 'organizedthemes' ),
						"desc" => __( 'The color of your headings (h1, h2, h3, h5, h6).', 'organizedthemes' ),
						"id" => "heading_color",
						"std" => "",
						"type" => "color");
	
	$options['menu_heading'] = array( "name" => __( 'Menu Heading', 'organizedthemes' ),
						"desc" => __( 'Sets the text color for the menu page headings.', 'organizedthemes' ),
						"id" => "menu_heading",
						"std" => "",
						"type" => "color");
	
	$options['menu_heading_background'] = array( "name" => __( 'Menu Heading Background', 'organizedthemes' ),
						"desc" => __( 'Sets the background color for the menu page headings.', 'organizedthemes' ),
						"id" => "menu_heading_background",
						"std" => "",
						"type" => "color");
	
	$options['navigation'] = array( 'name' => __( 'Navigation Items', 'organizedthemes' ),
			'desc' => __( 'Sets the type for your navigation menu.', 'organizedthemes' ),
			'id' => 'navigation',
			'std' => array( 'size' => '20px', 'face' => 'Rokkitt, serif', 'color' => '#ffffff'),
			'type' => 'typography',
			'options' => array(
				'faces' => options_typography_get_google_fonts(),
				'styles' => false,
				'color' => false )
			);
	
	$options['navigation_color'] = array( "name" => __( 'Navigation Color', 'organizedthemes' ),
						"desc" => __( 'The color of your navigation items.', 'organizedthemes' ),
						"id" => "navigation_color",
						"std" => "",
						"type" => "color");
	
	$options['navigation_hover'] = array( "name" => __( 'Navigation Hover Color', 'organizedthemes' ),
						"desc" => __( 'The color of your navigation items while hovering', 'organizedthemes' ),
						"id" => "navigation_hover",
						"std" => "",
						"type" => "color");
	
	$options[] = array(
		'name' => __('Other Styles', 'organizedthemes'),
		'type' => 'info');
							
	$options['link'] = array( "name" => __( 'Link Color', 'organizedthemes' ),
						"desc" => __( 'Sets the default color for links.', 'organizedthemes' ),
						"id" => "link",
						"std" => "",
						"type" => "color");
							
	$options['link_hover'] = array( "name" => __( 'Link Hover Color', 'organizedthemes' ),
						"desc" => __( 'Sets the color for links being hovered.', 'organizedthemes' ),
						"id" => "link_hover",
						"std" => "",
						"type" => "color");
											
	$options['button_text'] = array( "name" => __( 'Button Text', 'organizedthemes' ),
						"desc" => __( 'Sets the text color for buttons.', 'organizedthemes' ),
						"id" => "button_text",
						"std" => "",
						"type" => "color");
												
	$options['button_background'] = array( "name" => __( 'Button Background Color', 'organizedthemes' ),
						"desc" => __( 'Sets the background color for buttons.', 'organizedthemes' ),
						"id" => "button_background",
						"std" => "",
						"type" => "color");
												
	$options['button_text_hover'] = array( "name" => __( 'Button Text Hover', 'organizedthemes' ),
						"desc" => __( 'Sets the text color for buttons while hovering over them.', 'organizedthemes' ),
						"id" => "button_text_hover",
						"std" => "",
						"type" => "color");
																							
	$options['button_background_hover'] = array( "name" => __( 'Button Background Color Hover', 'organizedthemes' ),
						"desc" => __( 'Sets the button background color while hovering.', 'organizedthemes' ),
						"id" => "button_background_hover",
						"std" => "",
						"type" => "color");
															
	$options['content_background'] = array( "name" => __( 'Content Background Color', 'organizedthemes' ),
						"desc" => __( 'Sets the background color for the main content area.', 'organizedthemes' ),
						"id" => "content_background",
						"std" => "",
						"type" => "color");
															
	$options['sidebar_color'] = array( "name" => __( 'Sidebar Color', 'organizedthemes' ),
						"desc" => __( 'Sets the text color for the page/post sidebars and home page widgets.', 'organizedthemes' ),
						"id" => "sidebar_color",
						"std" => "",
						"type" => "color");
															
	$options['sidebar_background'] = array( "name" => __( 'Sidebar Background Color', 'organizedthemes' ),
						"desc" => __( 'Sets the color for the page/post sidebars background and home page widgets.', 'organizedthemes' ),
						"id" => "sidebar_background",
						"std" => "",
						"type" => "color");																						
																				
	$options['footer_color'] = array( "name" => __( 'Footer Color', 'organizedthemes' ),
						"desc" => __( 'Sets the text color for the footer.', 'organizedthemes' ),
						"id" => "footer_color",
						"std" => "",
						"type" => "color");
															
	$options['footer_background'] = array( "name" => __( 'Footer Background Color', 'organizedthemes' ),
						"desc" => __( 'Sets the color for the footer background.', 'organizedthemes' ),
						"id" => "footer_background",
						"std" => "",
						"type" => "color");	
															
	$options['comment_accent_color'] = array( "name" => __( 'Comments Area Accent Color', 'organizedthemes' ),
						"desc" => __( 'Color behind the author name and also the border for threaded comments.', 'organizedthemes' ),
						"id" => "comment_accent_color",
						"std" => "",
						"type" => "color");	
	
	$options[] = array(
		'name' => __('Advanced Style Settings', 'organizedthemes'),
		'desc' => __('', 'organizedthemes'),
		'type' => 'info');
	
	$options[] = array( 'name' => __( 'Disable Fonts', 'organizedthemes' ),
		'desc' => __( 'Turns off the output of Google fonts.', 'organizedthemes' ),
		'id' => 'disable_fonts',
		'std' => false,
		'type' => 'checkbox' );
				
							
	$options[] = array( "name" => __( 'Custom CSS', 'organizedthemes' ),
						"desc" => __( 'Add any custom CSS you would like to use here.', 'organizedthemes' ),
						"id" => "custom_css",
						"std" => "",
						"type" => "textarea"); 
	
						
	return $options;
}